require_relative 'hero'
require_relative 'level_turn'
require_relative 'jewel'
require_relative 'print_stats_mixin'


module DiabloGame
  class Level
    include PrintStats
    
    attr_reader :title
    
    def initialize(title)
      @title = title
      @heroes = []
    end

    def add_hero(insert)
      @heroes.push(insert)
    end

    def load_players(from_file)
      puts "\nLoading heroes from file path = #{from_file}:"
      File.readlines(from_file).each do |line|
        puts line
        name, health = line.split(',')
        hero = Hero.new(name, Integer(health))
        add_hero(hero)
      end
    end

    def play(stages)
      1.upto(stages) do |x|
        puts "\nStage #{x}".ljust(60,'.')
        puts "\nStarting round stats for stage #{x}:"
       
        @heroes.each do |hero|
          if hero.health >=0
            puts hero
          else 
            puts "xxx #{hero.name} is dead xxx"
          end
        end
        
        @heroes.each do |hero|
          if hero.health >= 0
            puts "\n"
            LevelTurn.take_turn(hero)
          else
            puts "\nxxx #{hero.name} is dead skip round xxx"
          end
        end

      end
       
    end

  end

end

if __FILE__ == $0
  puts "Test: level.rb".ljust(70,'.')
  level = DiabloGame::Level.new("Sanctuary")
  puts "Welcome to Act I: #{level.title}"

  level.load_players("/Users/howardmann/studio_game/diablo_game/bin/hero.csv")
  
  level.play(10)
  
  level.print_stats

end